@@ -131,11 +131,8 @@ def entry():
     # 必須の位置引数
     parser.add_argument("path", type=str, help="Path of directory where SPDX files are located")
 
-    # 必須のオプション引数
-    parser.add_argument(
-        "-p", "--person", nargs="+", type=str, required=True, help="The person that created the SPDX file"
-    )
     # オプション引数 変数名は長い方になる（p, oは省略形）
+    parser.add_argument("-p", "--person", nargs="+", type=str, help="The person that created the SPDX file")
     parser.add_argument("-o", "--organization", nargs="+", type=str, help="The organization that created the SPDX file")
 
     parser.add_argument(
@@ -168,6 +165,8 @@ def entry():
         args_person = " ".join(args.person)
     if args.organization is not None:
         args_organization = " ".join(args.organization)
+    if ((args.package is not None) or args.all) and ((args.person is None) or (args.organization is None)):
+        raise Exception("Enter Creator Name: person or organization")
     if not (0 <= args.mode <= 3 and 0 <= args.dep_mode <= 3):
         raise ValueError("Undefined mode")
 
